class Colorize:
    def __init__(self, dino, region_1=0, region_2=0, region_3=0, region_4=0, region_5=0, region_6=0):
        self.dino = dino
        self.region_1 = region_1
        self.region_2 = region_2
        self.region_3 = region_3
        self.region_4 = region_4
        self.region_5 = region_5
        self.region_6 = region_6

    def __str__(self):
        return "{} {} {} {} {} {}".format(self.region_1, self.region_2, self.region_3, self.region_4,
                                          self.region_5, self.region_6)


class ColorID:
    RED_ID = "1"
    BLUE_ID = "2"
    GREEN_ID = "3"
    YELLOW_ID = "4"
    CYAN_ID = "5"
    MAGENTA_ID = "6"
    LIGHT_GREEN_ID = "7"
    LIGHT_GREY_ID = "8"
    LIGHT_BROWN_ID = "9"
    LIGHT_ORANGE_ID = "10"
    LIGHT_YELLOW_ID = "11"
    LIGHT_RED_ID = "12"
    DARK_GREY_ID = "13"
    BLACK_ID = "14"
    BROWN_ID = "15"
    DARK_GREEN_ID = "16"
    DARK_RED_ID = "17"
    WHITE_ID = "18"
    DINO_LIGHT_RED_ID = "19"
    DINO_DARK_RED_ID = "20"
    DINO_LIGHT_ORANGE_ID = "21"
    DINO_DARK_ORANGE_ID = "22"
    DINO_LIGHT_YELLOW_ID = "23"
    DINO_DARK_YELLOW_ID = "24"
    DINO_LIGHT_GREEN_ID = "25"
    DINO_MEDIUM_GREEN_ID = "26"
    DINO_DARK_GREEN_ID = "27"
    DINO_LIGHT_BLUE_ID = "28"
    DINO_DARK_BLUE_ID = "29"
    DINO_LIGHT_PURPLE_ID = "30"
    DINO_DARK_PURPLE_ID = "31"
    DINO_LIGHT_BROWN_ID = "32"
    DINO_MEDIUM_BROWN_ID = "33"
    DINO_DARK_BROWN_ID = "34"
    DINO_DARKER_GREY_ID = "35"
    DINO_ALBINO_ID = "36"
    BIGFOOT0_ID = "37"
    BIGFOOT4_ID = "38"
    BIGFOOT5_ID = "39"
    WOLFFUR_ID = "40"
    DARKWOLFFUR_ID = "41"
    DRAGONBASE0_ID = "42"
    DRAGONBASE1_ID = "43"
    DRAGONFIRE_ID = "44"
    DRAGONGREEN0_ID = "45"
    DRAGONGREEN1_ID = "46"
    DRAGONGREEN2_ID = "47"
    DRAGONGREEN3_ID = "48"
    WYVERNPURPLE0_ID = "49"
    WYVERNPURPLE1_ID = "50"
    WYVERNBLUE0_ID = "51"
    WYVERNBLUE1_ID = "52"
    DINO_MEDIUM_BLUE_ID = "53"
    DINO_DEEP_BLUE_ID = "54"
    NEARWHITE_ID = "55"
    NEARBLACK_ID = "56"
    DARKTURQUOISE_ID = "57"
    MEDIUMTURQUOISE_ID = "58"
    TURQUOISE_ID = "59"
    GREENSLATE_ID = "60"
    SAGE_ID = "61"
    DARKWARMGRAY_ID = "62"
    MEDIUMWARMGRAY_ID = "63"
    LIGHTWARMGRAY_ID = "64"
    DARKCEMENT_ID = "65"
    LIGHTCEMENT_ID = "66"
    LIGHTPINK_ID = "67"
    DEEPPINK_ID = "68"
    DARKVIOLET_ID = "69"
    DARKMAGENTA_ID = "70"
    BURNTSIENNA_ID = "71"
    MEDIUMAUTUMN_ID = "72"
    VERMILLION_ID = "73"
    CORAL_ID = "74"
    ORANGE_ID = "75"
    PEACH_ID = "76"
    LIGHTAUTUMN_ID = "77"
    MUSTARD_ID = "78"
    ACTUALBLACK_ID = "79"
    MIDNIGHTBLUE_ID = "80"
    DARKBLUE_ID = "81"
    BLACKSANDS_ID = "82"
    LEMONLIME_ID = "83"
    MINT_ID = "84"
    JADE_ID = "85"
    PINEGREEN_ID = "86"
    SPRUCEGREEN_ID = "87"
    LEAFGREEN_ID = "88"
    DARKLAVENDER_ID = "89"
    MEDIUMLAVENDER_ID = "90"
    LAVENDER_ID = "91"
    DARKTEAL_ID = "92"
    MEDIUMTEAL_ID = "93"
    TEAL_ID = "94"
    POWDERBLUE_ID = "95"
    GLACIAL_ID = "96"
    CAMMO_ID = "97"
    DRYMOSS_ID = "98"
    CUSTARD_ID = "99"
    CREAM_ID = "100"

class ColorHex:
    RED_HEX = "ff0000"
    BLUE_HEX = "0000ff"
    GREEN_HEX = "00ff00"
    YELLOW_HEX = "ffff00"
    CYAN_HEX = "00ffff"
    MAGENTA_HEX = "ff00ff"
    LIGHT_GREEN_HEX = "c0ffba"
    LIGHT_GREY_HEX = "c8caca"
    LIGHT_BROWN_HEX = "786759"
    LIGHT_ORANGE_HEX = "ffb46c"
    LIGHT_YELLOW_HEX = "fffa8a"
    LIGHT_RED_HEX = "ff756c"
    DARK_GREY_HEX = "7b7b7b"
    BLACK_HEX = "3b3b3b"
    BROWN_HEX = "593a2a"
    DARK_GREEN_HEX = "224900"
    DARK_RED_HEX = "812118"
    WHITE_HEX = "ffffff"
    DINO_LIGHT_RED_HEX = "ffa8a8"
    DINO_DARK_RED_HEX = "592b2b"
    DINO_LIGHT_ORANGE_HEX = "ffb694"
    DINO_DARK_ORANGE_HEX = "88532f"
    DINO_LIGHT_YELLOW_HEX = "cacaa0"
    DINO_DARK_YELLOW_HEX = "94946c"
    DINO_LIGHT_GREEN_HEX = "e0ffe0"
    DINO_MEDIUM_GREEN_HEX = "799479"
    DINO_DARK_GREEN_HEX = "224122"
    DINO_LIGHT_BLUE_HEX = "d9e0ff"
    DINO_DARK_BLUE_HEX = "394263"
    DINO_LIGHT_PURPLE_HEX = "e4d9ff"
    DINO_DARK_PURPLE_HEX = "403459"
    DINO_LIGHT_BROWN_HEX = "ffe0ba"
    DINO_MEDIUM_BROWN_HEX = "948575"
    DINO_DARK_BROWN_HEX = "594e41"
    DINO_DARKER_GREY_HEX = "595959"
    DINO_ALBINO_HEX = "ffffff"
    BIGFOOT0_HEX = "b79683"
    BIGFOOT4_HEX = "eadad5"
    BIGFOOT5_HEX = "d0a794"
    WOLFFUR_HEX = "c3b39f"
    DARKWOLFFUR_HEX = "887666"
    DRAGONBASE0_HEX = "a0664b"
    DRAGONBASE1_HEX = "cb7956"
    DRAGONFIRE_HEX = "bc4f00"
    DRAGONGREEN0_HEX = "79846c"
    DRAGONGREEN1_HEX = "909c79"
    DRAGONGREEN2_HEX = "a5a48b"
    DRAGONGREEN3_HEX = "74939c"
    WYVERNPURPLE0_HEX = "787496"
    WYVERNPURPLE1_HEX = "b0a2c0"
    WYVERNBLUE0_HEX = "6281a"
    WYVERNBLUE1_HEX = "485c75"
    DINO_MEDIUM_BLUE_HEX = "5fa4ea"
    DINO_DEEP_BLUE_HEX = "4568d4"
    NEARWHITE_HEX = "ededed"
    NEARBLACK_HEX = "515151"
    DARKTURQUOISE_HEX = "184546"
    MEDIUMTURQUOISE_HEX = "007060"
    TURQUOISE_HEX = "00c5ab"
    GREENSLATE_HEX = "40594c"
    SAGE_HEX = "3e4f40"
    DARKWARMGRAY_HEX = "3b3938"
    MEDIUMWARMGRAY_HEX = "585554"
    LIGHTWARMGRAY_HEX = "9b9290"
    DARKCEMENT_HEX = "525b56"
    LIGHTCEMENT_HEX = "8aa196"
    LIGHTPINK_HEX = "e8b0ff"
    DEEPPINK_HEX = "ff119a"
    DARKVIOLET_HEX = "730046"
    DARKMAGENTA_HEX = "b70042"
    BURNTSIENNA_HEX = "7e331e"
    MEDIUMAUTUMN_HEX = "a93000"
    VERMILLION_HEX = "ef3100"
    CORAL_HEX = "ff5834"
    ORANGE_HEX = "ff7f00"
    PEACH_HEX = "ffa73a"
    LIGHTAUTUMN_HEX = "ae7000"
    MUSTARD_HEX = "949427"
    ACTUALBLACK_HEX = "171717"
    MIDNIGHTBLUE_HEX = "191d36"
    DARKBLUE_HEX = "152b3a"
    BLACKSANDS_HEX = "302531"
    LEMONLIME_HEX = "a8ff44"
    MINT_HEX = "38e985"
    JADE_HEX = "008840"
    PINEGREEN_HEX = "0f552e"
    SPRUCEGREEN_HEX = "005b45"
    LEAFGREEN_HEX = "5b9725"
    DARKLAVENDER_HEX = "5e275f"
    MEDIUMLAVENDER_HEX = "853587"
    LAVENDER_HEX = "bd77be"
    DARKTEAL_HEX = "0e404a"
    MEDIUMTEAL_HEX = "105563"
    TEAL_HEX = "14849c"
    POWDERBLUE_HEX = "82a7ff"
    GLACIAL_HEX = "aceaff"
    CAMMO_HEX = "505118"
    DRYMOSS_HEX = "766e3f"
    CUSTARD_HEX = "c0bd5e"
    CREAM_HEX = "f4ffc0"


class DyeID:
    BLACK_DYE_ID = "201"
    BLUE_DYE_ID = "202"
    BROWN_DYE_ID = "203"
    CYAN_DYE_ID = "204"
    FOREST_DYE_ID = "205"
    GREEN_DYE_ID = "206"
    UNCRAFTABLE_PURPLE_DYE_ID = "207"
    ORANGE_DYE_ID = "208"
    PARCHMENT_DYE_ID = "209"
    PINK_DYE_ID = "210"
    PURPLE_DYE_ID = "211"
    RED_DYE_ID = "212"
    ROYALTY_DYE_ID = "213"
    SILVER_DYE_ID = "214"
    SKY_DYE_ID = "215"
    TAN_DYE_ID = "216"
    TANGERINE_DYE_ID = "217"
    WHITE_DYE_ID = "218"
    YELLOW_DYE_ID = "219"
    MAGENTA_DYE_ID = "220"
    BRICK_DYE_ID = "221"
    CANTALOUPE_DYE_ID = "222"
    MUD_DYE_ID = "223"
    NAVY_DYE_ID = "224"
    OLIVE_DYE_ID = "225"
    SLATE_DYE_ID = "226"


class DyeHex:
    BLACK_DYE_HEX = "1f1f1f"
    BLUE_DYE_HEX = "0000ff"
    BROWN_DYE_HEX = "756147"
    CYAN_DYE_HEX = "00ffff"
    FOREST_DYE_HEX = "006c00"
    GREEN_DYE_HEX = "00ff00"
    UNCRAFTABLE_PURPLE_DYE_HEX = "6c00ba"
    ORANGE_DYE_HEX = "ff8800"
    PARCHMENT_DYE_HEX = "ffffba"
    PINK_DYE_HEX = "ff7be1"
    PURPLE_DYE_HEX = "7b00e0"
    RED_DYE_HEX = "ff0000"
    ROYALTY_DYE_HEX = "7b00a8"
    SILVER_DYE_HEX = "e0e0e0"
    SKY_DYE_HEX = "bad4ff"
    TAN_DYE_HEX = "ffed82"
    TANGERINE_DYE_HEX = "ad652c"
    WHITE_DYE_HEX = "fefefe"
    YELLOW_DYE_HEX = "ffff00"
    MAGENTA_DYE_HEX = "e71fd9"
    BRICK_DYE_HEX = "94341f"
    CANTALOUPE_DYE_HEX = "ff9a00"
    MUD_DYE_HEX = "473b2b"
    NAVY_DYE_HEX = "34346c"
    OLIVE_DYE_HEX = "baba59"
    SLATE_DYE_HEX = "595959"
