
class Dyes:
    BLACK_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Black.PrimalItemDye_Black'"
    BLUE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Blue.PrimalItemDye_Blue'"
    BRICK_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Brick.PrimalItemDye_Brick'"
    BROWN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Brown.PrimalItemDye_Brown'"
    CANTALOUPE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Cantaloupe.PrimalItemDye_Cantaloupe'"
    CYAN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Cyan.PrimalItemDye_Cyan'"
    FOREST_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Forest.PrimalItemDye_Forest'"
    GREEN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Green.PrimalItemDye_Green'"
    MAGENTA_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_ActuallyMagenta.PrimalItemDye_ActuallyMagenta'"
    MUD_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Mud.PrimalItemDye_Mud'"
    NAVY_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Navy.PrimalItemDye_Navy'"
    OLIVE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Olive.PrimalItemDye_Olive'"
    ORANGE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Orange.PrimalItemDye_Orange'"
    PARCHMENT_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Parchment.PrimalItemDye_Parchment'"
    PINK_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Pink.PrimalItemDye_Pink'"
    PURPLE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Purple.PrimalItemDye_Purple'"
    PURPLE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Magenta.PrimalItemDye_Magenta'"
    RED_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Red.PrimalItemDye_Red'"
    ROYALTY_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Royalty.PrimalItemDye_Royalty'"
    SILVER_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Silver.PrimalItemDye_Silver'"
    SKY_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Sky.PrimalItemDye_Sky'"
    SLATE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Slate.PrimalItemDye_Slate'"
    TAN_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Tan.PrimalItemDye_Tan'"
    TANGERINE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Tangerine.PrimalItemDye_Tangerine'"
    WHITE_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_White.PrimalItemDye_White'"
    YELLOW_COLORING = "Blueprint'/Game/PrimalEarth/CoreBlueprints/Items/PrimalItemDye_Yellow.PrimalItemDye_Yellow'"