class Island:
    CAVE_BEACON_1 = "SupplyCrate_Cave_QualityTier1_C"
    CAVE_BEACON_2 = "SupplyCrate_Cave_QualityTier2_C"
    CAVE_BEACON_3 = "SupplyCrate_Cave_QualityTier3_C"
    CAVE_BEACON_4 = "SupplyCrate_Cave_QualityTier4_C"
    SWAMP_CAVE_LOOT_CRATE_BLUE = "SupplyCrate_SwampCaveTier1_C"
    SWAMP_CAVE_LOOT_CRATE_YELLOW = "SupplyCrate_SwampCaveTier2_C"
    SWAMP_CAVE_LOOT_CRATE_RED = "SupplyCrate_SwampCaveTier3_C"
    ICE_CAVE_LOOT_CRATE_BLUE = "SupplyCrate_IceCaveTier1_C"
    ICE_CAVE_LOOT_CRATE_YELLOW = "SupplyCrate_IceCaveTier2_C"
    ICE_CAVE_LOOT_CRATE_RED = "SupplyCrate_IceCaveTier3_C"
    UNDERWATER_CAVES_LOOT_CRATE_BLUE = "SupplyCrate_UnderwaterCaveTier1_C"
    UNDERWATER_CAVES_LOOT_CRATE_YELLOW = "SupplyCrate_UnderwaterCaveTier2_C"
    UNDERWATER_CAVES_LOOT_CRATE_RED = "SupplyCrate_UnderwaterCaveTier3_C"
    DEEP_SEA_LOOT_CRATE = "SupplyCrate_OceanInstant_C"
    SUPPLYCRATE_OCEANINSTANT_HIGH_C = ""
    WHITE_BEACON = "SupplyCrate_Level03_C"
    WHITE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level03_Double_C"
    GREEN_BEACON = "SupplyCrate_Level15_C"
    GREEN_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level15_Double_C"
    BLUE_BEACON = "SupplyCrate_Level25_C"
    BLUE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level25_Double_C"
    PURPLE_BEACON = "SupplyCrate_Level35_C"
    PURPLE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level35_Double_C"
    YELLOW_BEACON = "SupplyCrate_Level45_C"
    YELLOW_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level45_Double_C"
    RED_BEACON = "SupplyCrate_Level60_C"
    RED_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level60_Double_C"
    BEAVER_DAM = "BeaverDam_C"
    GIANT_BEAVER_DAM_LOGS = "SupplyCrateBaseBP_Instantaneous_DamLogs_Child_C"
    GIANT_BEAVER_DAM = "SupplyCrateBaseBP_Instantaneous_DenLogs_Child2_C"



class Center:
    CAVE_BEACON_1 = "SupplyCrate_Cave_QualityTier1_C"
    CAVE_BEACON_2 = "SupplyCrate_Cave_QualityTier2_C"
    CAVE_BEACON_3 = "SupplyCrate_Cave_QualityTier3_C"
    CAVE_BEACON_4 = "SupplyCrate_Cave_QualityTier4_C"
    SWAMP_CAVE_LOOT_CRATE_BLUE = "SupplyCrate_SwampCaveTier1_C"
    SWAMP_CAVE_LOOT_CRATE_YELLOW = "SupplyCrate_SwampCaveTier2_C"
    SWAMP_CAVE_LOOT_CRATE_RED = "SupplyCrate_SwampCaveTier3_C"
    ICE_CAVE_LOOT_CRATE_BLUE = "SupplyCrate_IceCaveTier1_C"
    ICE_CAVE_LOOT_CRATE_YELLOW = "SupplyCrate_IceCaveTier2_C"
    ICE_CAVE_LOOT_CRATE_RED = "SupplyCrate_IceCaveTier3_C"
    UNDERWATER_CAVES_LOOT_CRATE_BLUE = "SupplyCrate_UnderwaterCaveTier1_C"
    UNDERWATER_CAVES_LOOT_CRATE_YELLOW = "SupplyCrate_UnderwaterCaveTier2_C"
    UNDERWATER_CAVES_LOOT_CRATE_RED = "SupplyCrate_UnderwaterCaveTier3_C"
    DEEP_SEA_LOOT_CRATE = "SupplyCrate_OceanInstant_C"
    SUPPLYCRATE_OCEANINSTANT_HIGH_C = ""
    WHITE_BEACON = "SupplyCrate_Level03_C"
    WHITE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level03_Double_C"
    GREEN_BEACON = "SupplyCrate_Level15_C"
    GREEN_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level15_Double_C"
    BLUE_BEACON = "SupplyCrate_Level25_C"
    BLUE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level25_Double_C"
    PURPLE_BEACON = "SupplyCrate_Level35_C"
    PURPLE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level35_Double_C"
    YELLOW_BEACON = "SupplyCrate_Level45_C"
    YELLOW_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level45_Double_C"
    RED_BEACON = "SupplyCrate_Level60_C"
    RED_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level60_Double_C"
    BEAVER_DAM = "BeaverDam_C"
    GIANT_BEAVER_DAM_LOGS = "SupplyCrateBaseBP_Instantaneous_DamLogs_Child_C"
    GIANT_BEAVER_DAM = "SupplyCrateBaseBP_Instantaneous_DenLogs_Child2_C"


class Valguero:
    pass


class Ragnarok:
    TREASURE_CHEST = "SupplyCrate_Chest_Treasure_JacksonL_C"
    CAVE_BEACON_1 = "SupplyCrate_Cave_QualityTier1_C"
    CAVE_BEACON_2 = "SupplyCrate_Cave_QualityTier2_C"
    CAVE_BEACON_3 = "SupplyCrate_Cave_QualityTier3_C"
    CAVE_BEACON_4 = "SupplyCrate_Cave_QualityTier4_C"
    SWAMP_CAVE_LOOT_CRATE_BLUE = "SupplyCrate_SwampCaveTier1_C"
    SWAMP_CAVE_LOOT_CRATE_YELLOW = "SupplyCrate_SwampCaveTier2_C"
    SWAMP_CAVE_LOOT_CRATE_RED = "SupplyCrate_SwampCaveTier3_C"
    ICE_CAVE_LOOT_CRATE_BLUE = "SupplyCrate_IceCaveTier1_C"
    ICE_CAVE_LOOT_CRATE_YELLOW = "SupplyCrate_IceCaveTier2_C"
    ICE_CAVE_LOOT_CRATE_RED = "SupplyCrate_IceCaveTier3_C"
    UNDERWATER_CAVES_LOOT_CRATE_BLUE = "SupplyCrate_UnderwaterCaveTier1_C"
    UNDERWATER_CAVES_LOOT_CRATE_YELLOW = "SupplyCrate_UnderwaterCaveTier2_C"
    UNDERWATER_CAVES_LOOT_CRATE_RED = "SupplyCrate_UnderwaterCaveTier3_C"
    DEEP_SEA_LOOT_CRATE = "SupplyCrate_OceanInstant_C"
    SUPPLYCRATE_OCEANINSTANT_HIGH_C = ""
    WHITE_BEACON = "SupplyCrate_Level03_C"
    WHITE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level03_Double_C"
    GREEN_BEACON = "SupplyCrate_Level15_C"
    GREEN_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level15_Double_C"
    BLUE_BEACON = "SupplyCrate_Level25_C"
    BLUE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level25_Double_C"
    PURPLE_BEACON = "SupplyCrate_Level35_C"
    PURPLE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level35_Double_C"
    YELLOW_BEACON = "SupplyCrate_Level45_C"
    YELLOW_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level45_Double_C"
    RED_BEACON = "SupplyCrate_Level60_C"
    RED_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level60_Double_C"
    CAVE_BEACON_1 = "SupplyCrate_Cave_QualityTier1_ScorchedEarth_C"
    CAVE_BEACON_2 = "SupplyCrate_Cave_QualityTier2_ScorchedEarth_C"
    CAVE_BEACON_3 = "SupplyCrate_Cave_QualityTier3_ScorchedEarth_C"
    WHITE_BEACON = "SupplyCrate_Level03_ScorchedEarth_C"
    WHITE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level03_Double_ScorchedEarth_C"
    GREEN_BEACON = "SupplyCrate_Level15_ScorchedEarth_C"
    GREEN_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level15_Double_ScorchedEarth_C"
    BLUE_BEACON = "SupplyCrate_Level30_ScorchedEarth_C"
    BLUE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level30_Double_ScorchedEarth_C"
    PURPLE_BEACON = "SupplyCrate_Level45_ScorchedEarth_C"
    PURPLE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level45_Double_ScorchedEarth_C"
    YELLOW_BEACON = "SupplyCrate_Level55_ScorchedEarth_C"
    YELLOW_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level55_Double_ScorchedEarth_C"
    RED_BEACON = "SupplyCrate_Level70_ScorchedEarth_C"
    RED_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level70_Double_ScorchedEarth_C"


class Extinction:
    CAVE_LOOT_CRATE_BLUE = "SupplyCrate_Cave_QualityTier1_EX_C"
    CAVE_LOOT_CRATE_YELLOW = "SupplyCrate_Cave_QualityTier2_EX_C"
    CAVE_LOOT_CRATE_RED = "SupplyCrate_Cave_QualityTier3_EX_C"
    ORBITAL_SUPPLY_DROP_BLUE = "SupplyCrate_Base_Horde_Easy_C"
    ORBITAL_SUPPLY_DROP_YELLOW = "SupplyCrate_Base_Horde_Medium_C"
    ORBITAL_SUPPLY_DROP_RED = "SupplyCrate_Base_Horde_Hard_C"
    ORBITAL_SUPPLY_DROP_PURPLE = "SupplyCrate_Base_Horde_Legendary_C"
    CORRUPT_ELEMENT_NODE_EASY = "ElementNode_Easy_Horde_C"
    CORRUPT_ELEMENT_NODE_HARD = "ElementNode_Hard_Horde_C"
    CORRUPT_ELEMENT_NODE_MEDIUM = "ElementNode_Medium_Horde_C"
    CORRUPT_ELEMENT_NODE_KINGKAIJU = "KingKaiju_ElementNode_C"
    ARTIFACT_CONTAINER_CHAOS = "ArtifactCrate_Desert_Kaiju_EX_C"
    ARTIFACT_CONTAINER_GROWTH = "ArtifactCrate_ForestKaiju_EX_C"
    ARTIFACT_CONTAINER_VOID = "ArtifactCrate_IceKaiju_EX_C"
    KING_TITAN_ALPHA = "ArtifactCrate_KingKaiju_Alpha_EX_C"
    KING_TITAN_BETA = "ArtifactCrate_KingKaiju_Beta_EX_C"
    KING_TITAN_GAMMA = "ArtifactCrate_KingKaiju_EX_C"


class Aberration:
    WHITE_CRATE = "SupplyCrate_Cave_Aberration_Level10_C"
    WHITE_CRATE_DOUBLE = "SupplyCrate_Cave_Aberration_Level10_Double_C"
    GREEN_CRATE = "SupplyCrate_Cave_Aberration_Level25_C"
    GREEN_CRATE_DOUBLE = "SupplyCrate_Cave_Aberration_Level25_Double_C"
    BLUE_CRATE = "SupplyCrate_Cave_Aberration_Level35_C"
    BLUE_CRATE_DOUBLE = "SupplyCrate_Cave_Aberration_Level35_Double_C"
    PURPLE_CRATE = "SupplyCrate_Cave_Aberration_Level50_C"
    PURPLE_CRATE_DOUBLE = "SupplyCrate_Cave_Aberration_Level50_Double_C"
    YELLOW_CRATE = "SupplyCrate_Cave_Aberration_Level65_C"
    YELLOW_CRATE_DOUBLE = "SupplyCrate_Cave_Aberration_Level65_Double_C"
    RED_CRATE = "SupplyCrate_Cave_Aberration_Level80_C"
    RED_CRATE_DOUBLE = "SupplyCrate_Cave_Aberration_Level80_Double_C"
    BLUE_DUNGEON_CRATE = "SupplyCrate_Dungeon_Aberration_Level35_C"
    PURPLE_DUNGEON_CRATE = "SupplyCrate_Dungeon_Aberration_Level50_C"
    YELLOW_DUNGEON_CRATE = "SupplyCrate_Dungeon_Aberration_Level65_C"
    RED_DUNGEON_CRATE = "SupplyCrate_Dungeon_Aberration_Level80_C"
    BLUE_SURFACE_BEACON = "SupplyCrate_Level35_Aberrant_Surface_C"
    BLUE_SURFACE_BEACON_DOUBLE = "SupplyCrate_Level35_Aberrant_Surface_Double_C"
    PURPLE_SURFACE_BEACON = "SupplyCrate_Level50_Aberrant_Surface_C"
    PURPLE_SURFACE_BEACON_DOUBLE = "SupplyCrate_Level50_Aberrant_Surface_Double_C"
    YELLOW_SURFACE_BEACON = "SupplyCrate_Level65_Aberrant_Surface_C"
    YELLOW_SURFACE_BEACON_DOUBLE = "SupplyCrate_Level65_Aberrant_Surface_Double_C"
    RED_SURFACE_BEACON = "SupplyCrate_Level80_Aberrant_Surface_C"
    RED_SURFACE_BEACON_DOUBLE = "SupplyCrate_Level80_Aberrant_Surface_Double_C"
    ARTIFACT_CONTAINER_DEPTHS = "ArtifactCrate_AB_C"
    ARTIFACT_CONTAINER_SHADOWS = "ArtifactCrate_2_AB_C"
    ARTIFACT_CONTAINER_STALKER = "ArtifactCrate_3_AB_C"
    ARTIFACT_CONTAINER_LOST = "ArtifactCrate_4_AB_C"


class Scortched:
    CAVE_BEACON_1 = "SupplyCrate_Cave_QualityTier1_ScorchedEarth_C"
    CAVE_BEACON_2 = "SupplyCrate_Cave_QualityTier2_ScorchedEarth_C"
    CAVE_BEACON_3 = "SupplyCrate_Cave_QualityTier3_ScorchedEarth_C"
    WHITE_BEACON = "SupplyCrate_Level03_ScorchedEarth_C"
    WHITE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level03_Double_ScorchedEarth_C"
    GREEN_BEACON = "SupplyCrate_Level15_ScorchedEarth_C"
    GREEN_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level15_Double_ScorchedEarth_C"
    BLUE_BEACON = "SupplyCrate_Level30_ScorchedEarth_C"
    BLUE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level30_Double_ScorchedEarth_C"
    PURPLE_BEACON = "SupplyCrate_Level45_ScorchedEarth_C"
    PURPLE_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level45_Double_ScorchedEarth_C"
    YELLOW_BEACON = "SupplyCrate_Level55_ScorchedEarth_C"
    YELLOW_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level55_Double_ScorchedEarth_C"
    RED_BEACON = "SupplyCrate_Level70_ScorchedEarth_C"
    RED_BEACON_DOUBLE_ITEMS = "SupplyCrate_Level70_Double_ScorchedEarth_C"
    ARTIFACT_CONTAINER_DESTROYER = "ArtifactCrate_SE_C"
    ARTIFACT_CONTAINER_GATEKEEPER = "ArtifactCrate_2_SE_C"
    ARTIFACT_CONTAINER_CRAG = "ArtifactCrate_3_SE_C"


class Genesis2:
    AMBERGRIS_CRATE = "SupplyCrate_Space_01_Ambergris_C"
    CRYSTAL_CRATE = "SupplyCrate_Space_02_Crystal_C"
    SULFUR_CRATE = "SupplyCrate_Space_03_Sulfur_C"
    ELEMENTSHARDS_CRATE = "SupplyCrate_Space_04_Elementshards_C"
    OBSIDIAN_CRATE = "SupplyCrate_Space_05_Obsidian_C"
    OIL_CRATE = "SupplyCrate_Space_06_Oil_C"
    ELEMENTDUST_CRATE = "SupplyCrate_Space_07_Elementdust_C"
    BLACKPEARLS_CRATE = "SupplyCrate_Space_08_Blackpearls_C"


class Genesis1:
    pass
